@@ -77,7 +77,7 @@ class Room():
         Arguments:
             message (string): the message to send
         """
-        self.send(f"{self.id}|{message}")
+        self.connection.send(f"{self.id}|{message}")
 
     def leave(self):
         """Leaves the room
@@ -87,7 +87,7 @@ class Room():
     def join(self):
         """Joins the room
         """
-        self.send(f'|/j {self.id}')
+        self.connection.send(f'|/join {self.id}')
         self.connection.roomList.add(self)
         self.say(f'/cmd roominfo {self.id}')
 
